TRUE if x is binned counts or FALSE if x is
data matrix
se
flag for computing standard error of kernel
estimate
estimate.positive
flag for ensuring all estimate values are positive
Value
Returns a list with fields
x.grid - grid points
est - kernel estimate of partial derivative of density function
indicated by drvse - estimate of standard error of est (if se=TRUE).
Details
The estimates and standard errors are computed over a grid of binned counts
x.grid. If the binned counts are not supplied then they are computed
inside this function.
If gridsize and range.x are not supplied, they are
computed inside this function.