For d=1, if h is missing, the default bandwidth is hpi.
For d>1, if H is missing, the default is Hpi.
For d=1, if positive=TRUE then x is transformed to
log(x+adj.positive) where the default adj.positive is
the minimum of x. This is known as a log transformation density
estimate. If unit.interval=TRUE then x is transformed to
qnorm(x). See kde.boundary for boundary kernel density estimates, as these tend to be more robust than transformation density estimates.
For d=1, 2, 3, and if eval.points is not specified, then the
density estimate is computed over a grid
defined by gridsize (if binned=FALSE) or
by bgridsize (if binned=TRUE). This form is suitable for
visualisation in conjunction with the plot method.
For d=4, 5, 6, and if eval.points is not specified, then the
density estimate is computed over a grid defined by gridsize.
If eval.points is specified, as a vector (d=1) or
as a matrix (d=2, 3, 4), then the density estimate is computed at
eval.points. This form is suitable for numerical summaries
(e.g. maximum likelihood), and is not compatible with the plot
method. Despite that the density estimate is returned only at
eval.points, by default, a binned gridded estimate is
calculated first and then the density estimate at eval.points
is computed using the predict method. If this default intermediate
binned grid estimate is not required, then set binned=FALSE to
compute directly the exact density estimate at eval.points.
Binned kernel estimation is an approximation to the exact kernel
estimation and is available for d=1, 2, 3, 4. This makes
kernel estimators feasible for large samples. The default value of the
binning flag binned is n>1 (d=1), n>500 (d=2), n>1000 (d>=3).
Some times binned estimation leads to negative density values: if non-negative
values are required, then set density=TRUE.
The default bgridsize,gridsize are d=1: 401; d=2: rep(151, 2); d=3:
rep(51, 3); d=4: rep(21, 4).
The effective support for a normal kernel is where
all values outside [-supp,supp]^d are zero.
The default xmin is min(x)-Hmax*supp and xmax
is max(x)+Hmax*supp where Hmax is the maximum of the
diagonal elements of H. The grid produced is the outer
product of c(xmin[1], xmax[1]), ..., c(xmin[d], xmax[d]).
For ks \(\geq\) 1.14.0, when binned=TRUE and xmin,xmax
are not missing, the data values x are clipped to the estimation grid
delimited by xmin,xmax to prevent potential memory leaks.