This data set contains the cardiotocographic measurements from healthy,
suspect and pathological foetuses.
Usage
data(cardio)
Arguments
Format
A matrix with 2126 rows and 8 columns.
Each row corresponds to a foetal cardiotocogram. The
class label for the foetal state is the last column: N = normal, S =
suspect, P = pathological. Details for all variables are found in the
link below.