Kernel copula and copula density estimator for 2-dimensional data.
kcopula(x, H, hs, gridsize, gridtype, xmin, xmax, supp=3.7, eval.points,
binned, bgridsize, w, marginal="kernel", verbose=FALSE)
kcopula.de(x, H, gridsize, gridtype, xmin, xmax, supp=3.7, eval.points,
binned, bgridsize, w, compute.cont=TRUE, approx.cont=TRUE,
marginal="kernel", boundary.supp, boundary.kernel="beta", verbose=FALSE)A kernel copula estimate, output from kcopula, is an object of
class kcopula. A kernel copula density estimate, output from
kcopula.de, is an object of class kde. These two classes
of objects have the same fields as kcde and kde objects
respectively, except for
pseudo-uniform data points
data points - same as input
marginal function used to compute pseudo-uniform data
flag for data points in the boundary region
(kcopula.de only)
matrix of data values
bandwidth matrix. If these are missing, Hpi.kcde/Hpi or hpi.kcde/hpi is called by default.
vector of number of grid points
not yet implemented
vector of minimum/maximum values for grid
effective support for standard normal
matrix of points at which estimate is evaluated
flag for binned estimation
vector of binning grid sizes
vector of weights. Default is a vector of all ones.
"kernel" = kernel cdf or "empirical" = empirical cdf to calculate pseudo-uniform values. Default is "kernel".
flag for computing 1% to 99% probability contour levels. Default is TRUE.
flag for computing approximate probability contour levels. Default is TRUE.
effective support for boundary region
"beta" = beta boundary kernel, "linear" = linear boundary kernel
flag to print out progress information. Default is FALSE.
For kernel copula estimates, a transformation approach is used to
account for the boundary effects. If H is missing, the default
is Hpi.kcde; if hs are missing, the default is
hpi.kcde.
For kernel copula density estimates, for those points which are in
the interior region, the usual kernel density estimator
(kde) is used. For those points in the boundary region,
a product beta kernel based on the boundary corrected univariate beta
kernel of Chen (1999) is used (kde.boundary). If H
is missing, the default is Hpi.kcde; if hs are missing,
the default is hpi.
The effective support, binning, grid size, grid range parameters are
the same as for kde.
Duong, T. (2014) Optimal data-based smoothing for non-parametric estimation of copula functions and their densities. Submitted.
Chen, S.X. (1999). Beta kernel estimator for density functions. Computational Statistics & Data Analysis 31, 131--145.
kcde, kde
data(fgl, package="MASS")
x <- fgl[,c("RI", "Na")]
Chat <- kcopula(x=x)
plot(Chat, display="filled.contour", lwd=1)
plot(Chat, display="persp", border=1)
Run the code above in your browser using DataLab