Kernel density derivative estimate for 1- to 6-dimensional data.
kdde(x, H, h, deriv.order=0, gridsize, gridtype, xmin, xmax, supp=3.7,
eval.points, binned, bgridsize, positive=FALSE, adj.positive, w,
deriv.vec=TRUE, verbose=FALSE)
kcurv(fhat, compute.cont=TRUE)# S3 method for kdde
predict(object, ..., x)
A kernel density derivative estimate is an object of class
kdde which is a list with fields:
data points - same as input
vector or list of points at which the estimate is evaluated
density derivative estimate at eval.points
scalar bandwidth (1-d only)
bandwidth matrix
"linear"
flag for estimation on a grid
flag for binned estimation
variable names
vector of weights
derivative order (scalar)
martix where each row is a vector of partial derivative indices
matrix of data values
bandwidth matrix/scalar bandwidth. If these are missing, Hpi or hpi is called by default.
derivative order (scalar)
vector of number of grid points
not yet implemented
vector of minimum/maximum values for grid
effective support for standard normal
vector or matrix of points at which estimate is evaluated
flag for binned estimation
vector of binning grid sizes
flag if data are positive (1-d, 2-d). Default is FALSE.
adjustment applied to positive 1-d data
vector of weights. Default is a vector of all ones.
flag to compute all derivatives in vectorised derivative. Default is TRUE. If FALSE then only the unique derivatives are computed.
flag to print out progress information. Default is FALSE.
flag for computing 1% to 99% probability contour levels. Default is TRUE.
object of class kdde with deriv.order=2
object of class kdde
other parameters
For each partial derivative, for grid estimation, the estimate is a
list whose elements
correspond to the partial derivative indices in the rows of deriv.ind.
For points estimation, the estimate is a matrix whose columns correspond to
the rows of deriv.ind.
If the bandwidth H is missing from kdde, then
the default bandwidth is the plug-in selector
Hpi. Likewise for missing h.
The effective support, binning, grid size, grid range, positive
parameters are the same as kde.
The summary curvature is computed by kcurv, i.e.
$$\hat{s}(\bold{x})= - \bold{1}\{\mathsf{D}^2 \hat{f}(\bold{x}) <
0\} \mathrm{abs}(|\mathsf{D}^2 \hat{f}(\bold{x})|)$$ where \(\mathsf{D}^2
\hat{f}(\bold{x})\) is the kernel Hessian matrix
estimate. So \(\hat{s}\) calculates the absolute value of
the determinant of the Hessian matrix and whose sign is the opposite of
the negative definiteness indicator.
kde, plot.kdde
set.seed(8192)
x <- rmvnorm.mixt(1000, mus=c(0,0), Sigmas=invvech(c(1,0.8,1)))
fhat <- kdde(x=x, deriv.order=1) ## gradient [df/dx, df/dy]
predict(fhat, x=x[1:5,])
## See other examples in ? plot.kdde
Run the code above in your browser using DataLab